@@ -1,6 +1,6 @@
 from decimal import Decimal
 from pprint import pformat
-from typing import Optional, Union
+from typing import Any, Dict, Optional, Union
 
 from deprecation import deprecated  # type: ignore
 
@@ -143,6 +143,7 @@ class ContractCall(ContextMixin):
         level=None,
         now=None,
         self_address=None,
+        view_results: Optional[Dict[str, Any]] = None,
     ) -> ContractCallResult:
         """Run code in the builtin REPL (WARNING! Not recommended for critical tasks).
 
@@ -155,6 +156,7 @@ class ContractCall(ContextMixin):
         :param level: patch LEVEL
         :param now: patch NOW
         :param self_address: patch SELF/SELF_ADDRESS
+        :param view_results: patch VIEW calls (keys must be string "address%view", values => Python objects)
         :rtype: pytezos.contract.result.ContractCallResult
         """
         storage_ty = StorageSection.match(self.context.storage_expr)
@@ -176,6 +178,7 @@ class ContractCall(ContextMixin):
             level=level,
             now=now,
             address=self_address,
+            view_results=view_results,
         )
         if error:
             logger.debug('\n'.join(stdout))
@@ -243,7 +246,7 @@ class ContractCall(ContextMixin):
         assert len(results) == 1
         return results[0]
 
-    @deprecated(deprecated_in='3.0.0', removed_in='3.1.0', details='use either `run_code` or `run_operation`')
+    @deprecated(deprecated_in='3.0.0', removed_in='4.0.0', details='use either `run_code` or `run_operation`')
     def result(self, storage=None, source=None, sender=None, gas_limit=None) -> ContractCallResult:
         """Simulate operation and parse the result.
 
@@ -284,6 +287,6 @@ class ContractCall(ContextMixin):
             raise Exception('Multiple internal operations, not sure which one to pick')
         return operations[0]
 
-    @deprecated(deprecated_in='3.0.4', removed_in='3.1.0', details='Use callback_view instead')
+    @deprecated(deprecated_in='3.0.4', removed_in='4.0.0', details='Use callback_view instead')
     def view(self):
         return self.callback_view()
